@@ -2,6 +2,7 @@ package s3
 
 import (
 	"fmt"
+	"strings"
 
 	"github.com/rclone/gofakes3"
 	"github.com/rclone/rclone/fs"
@@ -12,25 +13,23 @@ type logger struct{}
 
 // print log message
 func (l logger) Print(level gofakes3.LogLevel, v ...any) {
-	var s string
-	if len(v) == 0 {
-		s = ""
-	} else {
-		var ok bool
-		s, ok = v[0].(string)
-		if !ok {
-			s = fmt.Sprint(v[0])
+	var b strings.Builder
+	for i := range v {
+		if i > 0 {
+			fmt.Fprintf(&b, " ")
 		}
-		v = v[1:]
+		fmt.Fprint(&b, v[i])
 	}
+	s := b.String()
+
 	switch level {
 	default:
 		fallthrough
 	case gofakes3.LogErr:
-		fs.Errorf("serve s3", s, v...)
+		fs.Errorf("serve s3", s)
 	case gofakes3.LogWarn:
-		fs.Infof("serve s3", s, v...)
+		fs.Infof("serve s3", s)
 	case gofakes3.LogInfo:
-		fs.Debugf("serve s3", s, v...)
+		fs.Debugf("serve s3", s)
 	}
 }
