@@ -8,6 +8,7 @@ import (
 	"errors"
 	"fmt"
 	"math/rand"
+	"net"
 	"net/http"
 	"strings"
 
@@ -15,7 +16,6 @@ import (
 	"github.com/rclone/gofakes3"
 	"github.com/rclone/gofakes3/signature"
 	"github.com/rclone/rclone/cmd/serve/proxy"
-	"github.com/rclone/rclone/cmd/serve/proxy/proxyflags"
 	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/hash"
 	httplib "github.com/rclone/rclone/lib/http"
@@ -29,67 +29,70 @@ const (
 	ctxKeyID ctxKey = iota
 )
 
-// Options contains options for the http Server
-type Options struct {
-	//TODO add more options
-	pathBucketMode bool
-	hashName       string
-	hashType       hash.Type
-	authPair       []string
-	noCleanup      bool
-	Auth           httplib.AuthConfig
-	HTTP           httplib.Config
-}
-
 // Server is a s3.FileSystem interface
 type Server struct {
-	server   *httplib.Server
-	f        fs.Fs
-	_vfs     *vfs.VFS // don't use directly, use getVFS
-	faker    *gofakes3.GoFakeS3
-	handler  http.Handler
-	proxy    *proxy.Proxy
-	ctx      context.Context // for global config
-	s3Secret string
+	server       *httplib.Server
+	opt          Options
+	f            fs.Fs
+	_vfs         *vfs.VFS // don't use directly, use getVFS
+	faker        *gofakes3.GoFakeS3
+	handler      http.Handler
+	proxy        *proxy.Proxy
+	ctx          context.Context // for global config
+	s3Secret     string
+	etagHashType hash.Type
 }
 
 // Make a new S3 Server to serve the remote
-func newServer(ctx context.Context, f fs.Fs, opt *Options) (s *Server, err error) {
+func newServer(ctx context.Context, f fs.Fs, opt *Options, vfsOpt *vfscommon.Options, proxyOpt *proxy.Options) (s *Server, err error) {
 	w := &Server{
-		f:   f,
-		ctx: ctx,
+		f:            f,
+		ctx:          ctx,
+		opt:          *opt,
+		etagHashType: hash.None,
 	}
 
-	if len(opt.authPair) == 0 {
+	if w.opt.EtagHash == "auto" {
+		w.etagHashType = f.Hashes().GetOne()
+	} else if w.opt.EtagHash != "" {
+		err := w.etagHashType.Set(w.opt.EtagHash)
+		if err != nil {
+			return nil, err
+		}
+	}
+	if w.etagHashType != hash.None {
+		fs.Debugf(f, "Using hash %v for ETag", w.etagHashType)
+	}
+
+	if len(opt.AuthKey) == 0 {
 		fs.Logf("serve s3", "No auth provided so allowing anonymous access")
 	} else {
-		w.s3Secret = getAuthSecret(opt.authPair)
+		w.s3Secret = getAuthSecret(opt.AuthKey)
 	}
 
 	var newLogger logger
 	w.faker = gofakes3.New(
-		newBackend(w, opt),
-		gofakes3.WithHostBucket(!opt.pathBucketMode),
+		newBackend(w),
+		gofakes3.WithHostBucket(!opt.ForcePathStyle),
 		gofakes3.WithLogger(newLogger),
 		gofakes3.WithRequestID(rand.Uint64()),
 		gofakes3.WithoutVersioning(),
-		gofakes3.WithV4Auth(authlistResolver(opt.authPair)),
+		gofakes3.WithV4Auth(authlistResolver(opt.AuthKey)),
 		gofakes3.WithIntegrityCheck(true), // Check Content-MD5 if supplied
 	)
 
-	w.handler = http.NewServeMux()
 	w.handler = w.faker.Server()
 
-	if proxyflags.Opt.AuthProxy != "" {
-		w.proxy = proxy.New(ctx, &proxyflags.Opt)
+	if proxy.Opt.AuthProxy != "" {
+		w.proxy = proxy.New(ctx, proxyOpt, vfsOpt)
 		// proxy auth middleware
 		w.handler = proxyAuthMiddleware(w.handler, w)
 		w.handler = authPairMiddleware(w.handler, w)
 	} else {
-		w._vfs = vfs.New(f, &vfscommon.Opt)
+		w._vfs = vfs.New(f, vfsOpt)
 
-		if len(opt.authPair) > 0 {
-			w.faker.AddAuthKeys(authlistResolver(opt.authPair))
+		if len(opt.AuthKey) > 0 {
+			w.faker.AddAuthKeys(authlistResolver(opt.AuthKey))
 		}
 	}
 
@@ -101,6 +104,9 @@ func newServer(ctx context.Context, f fs.Fs, opt *Options) (s *Server, err error
 		return nil, fmt.Errorf("failed to init server: %w", err)
 	}
 
+	router := w.server.Router()
+	w.Bind(router)
+
 	return w, nil
 }
 
@@ -122,7 +128,7 @@ func (w *Server) getVFS(ctx context.Context) (VFS *vfs.VFS, err error) {
 }
 
 // auth does proxy authorization
-func (w *Server) auth(accessKeyID string) (value interface{}, err error) {
+func (w *Server) auth(accessKeyID string) (value any, err error) {
 	VFS, _, err := w.proxy.Call(stringToMd5Hash(accessKeyID), accessKeyID, false)
 	if err != nil {
 		return nil, err
@@ -135,13 +141,24 @@ func (w *Server) Bind(router chi.Router) {
 	router.Handle("/*", w.handler)
 }
 
-// Serve serves the s3 server
+// Serve serves the s3 server until the server is shutdown
 func (w *Server) Serve() error {
 	w.server.Serve()
 	fs.Logf(w.f, "Starting s3 server on %s", w.server.URLs())
+	w.server.Wait()
 	return nil
 }
 
+// Addr returns the first address of the server
+func (w *Server) Addr() net.Addr {
+	return w.server.Addr()
+}
+
+// Shutdown the server
+func (w *Server) Shutdown() error {
+	return w.server.Shutdown()
+}
+
 func authPairMiddleware(next http.Handler, ws *Server) http.Handler {
 	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		accessKey, _ := parseAccessKeyID(r)
