@@ -4,10 +4,12 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"log"
+	"log/slog"
 	"os"
+	"slices"
+	"strings"
 
-	"github.com/sirupsen/logrus"
+	"github.com/rclone/rclone/lib/caller"
 )
 
 // LogLevel describes rclone's logs.  These are a subset of the syslog log levels.
@@ -33,6 +35,7 @@ const (
 	LogLevelNotice // Normal logging, -q suppresses
 	LogLevelInfo   // Transfers, needs -v
 	LogLevelDebug  // Debug level, needs -vv
+	LogLevelOff
 )
 
 type logLevelChoices struct{}
@@ -47,6 +50,7 @@ func (logLevelChoices) Choices() []string {
 		LogLevelNotice:    "NOTICE",
 		LogLevelInfo:      "INFO",
 		LogLevelDebug:     "DEBUG",
+		LogLevelOff:       "OFF",
 	}
 }
 
@@ -54,25 +58,39 @@ func (logLevelChoices) Type() string {
 	return "LogLevel"
 }
 
-// LogPrintPid enables process pid in log
-var LogPrintPid = false
+// slogLevel definitions defined as slog.Level constants.
+// The integer values determine severity for filtering.
+// Lower values are less severe (e.g., Debug), higher values are more severe (e.g., Emergency).
+// We fit our extra values into slog's scale.
+const (
+	// slog.LevelDebug   slog.Level = -4
+	// slog.LevelInfo    slog.Level = 0
+	SlogLevelNotice = slog.Level(2) // Between Info (0) and Warn (4)
+	// slog.LevelWarn    slog.Level = 4
+	// slog.LevelError   slog.Level = 8
+	SlogLevelCritical  = slog.Level(12) // More severe than Error
+	SlogLevelAlert     = slog.Level(16) // More severe than Critical
+	SlogLevelEmergency = slog.Level(20) // Most severe
+	SlogLevelOff       = slog.Level(24) // A very high value
+)
 
-// InstallJSONLogger is a hook that --use-json-log calls
-var InstallJSONLogger = func(logLevel LogLevel) {}
-
-// LogOutput sends the text to the logger of level
-var LogOutput = func(level LogLevel, text string) {
-	text = fmt.Sprintf("%-6s: %s", level, text)
-	if LogPrintPid {
-		text = fmt.Sprintf("[%d] %s", os.Getpid(), text)
-	}
-	_ = log.Output(4, text)
+// Map our level numbers to slog level numbers
+var levelToSlog = []slog.Level{
+	LogLevelEmergency: SlogLevelEmergency,
+	LogLevelAlert:     SlogLevelAlert,
+	LogLevelCritical:  SlogLevelCritical,
+	LogLevelError:     slog.LevelError,
+	LogLevelWarning:   slog.LevelWarn,
+	LogLevelNotice:    SlogLevelNotice,
+	LogLevelInfo:      slog.LevelInfo,
+	LogLevelDebug:     slog.LevelDebug,
+	LogLevelOff:       SlogLevelOff,
 }
 
 // LogValueItem describes keyed item for a JSON log entry
 type LogValueItem struct {
 	key    string
-	value  interface{}
+	value  any
 	render bool
 }
 
@@ -80,7 +98,7 @@ type LogValueItem struct {
 // augment the JSON output with more structured information.
 //
 // key is the dictionary parameter used to store value.
-func LogValue(key string, value interface{}) LogValueItem {
+func LogValue(key string, value any) LogValueItem {
 	return LogValueItem{key: key, value: value, render: true}
 }
 
@@ -91,7 +109,7 @@ func LogValue(key string, value interface{}) LogValueItem {
 //
 // String() will return a blank string - this is useful to put items
 // in which don't print into the log.
-func LogValueHide(key string, value interface{}) LogValueItem {
+func LogValueHide(key string, value any) LogValueItem {
 	return LogValueItem{key: key, value: value, render: false}
 }
 
@@ -108,87 +126,56 @@ func (j LogValueItem) String() string {
 	return fmt.Sprint(j.value)
 }
 
-func logLogrus(level LogLevel, text string, fields logrus.Fields) {
-	switch level {
-	case LogLevelDebug:
-		logrus.WithFields(fields).Debug(text)
-	case LogLevelInfo:
-		logrus.WithFields(fields).Info(text)
-	case LogLevelNotice, LogLevelWarning:
-		logrus.WithFields(fields).Warn(text)
-	case LogLevelError:
-		logrus.WithFields(fields).Error(text)
-	case LogLevelCritical:
-		logrus.WithFields(fields).Fatal(text)
-	case LogLevelEmergency, LogLevelAlert:
-		logrus.WithFields(fields).Panic(text)
+// LogLevelToSlog converts an rclone log level to log/slog log level.
+func LogLevelToSlog(level LogLevel) slog.Level {
+	slogLevel := slog.LevelError
+	// NB level is unsigned so we don't check < 0 here
+	if int(level) < len(levelToSlog) {
+		slogLevel = levelToSlog[level]
 	}
+	return slogLevel
 }
 
-func logLogrusWithObject(level LogLevel, o interface{}, text string, fields logrus.Fields) {
+func logSlog(level LogLevel, text string, attrs []any) {
+	slog.Log(context.Background(), LogLevelToSlog(level), text, attrs...)
+}
+
+func logSlogWithObject(level LogLevel, o any, text string, attrs []any) {
 	if o != nil {
-		if fields == nil {
-			fields = logrus.Fields{}
-		}
-		fields["object"] = fmt.Sprintf("%+v", o)
-		fields["objectType"] = fmt.Sprintf("%T", o)
+		attrs = slices.Concat(attrs, []any{
+			"object", fmt.Sprintf("%+v", o),
+			"objectType", fmt.Sprintf("%T", o),
+		})
 	}
-	logLogrus(level, text, fields)
-}
-
-func logJSON(level LogLevel, o interface{}, text string) {
-	logLogrusWithObject(level, o, text, nil)
-}
-
-func logJSONf(level LogLevel, o interface{}, text string, args ...interface{}) {
-	text = fmt.Sprintf(text, args...)
-	fields := logrus.Fields{}
-	for _, arg := range args {
-		if item, ok := arg.(LogValueItem); ok {
-			fields[item.key] = item.value
-		}
-	}
-	logLogrusWithObject(level, o, text, fields)
-}
-
-func logPlain(level LogLevel, o interface{}, text string) {
-	if o != nil {
-		text = fmt.Sprintf("%v: %s", o, text)
-	}
-	LogOutput(level, text)
-}
-
-func logPlainf(level LogLevel, o interface{}, text string, args ...interface{}) {
-	logPlain(level, o, fmt.Sprintf(text, args...))
+	logSlog(level, text, attrs)
 }
 
 // LogPrint produces a log string from the arguments passed in
-func LogPrint(level LogLevel, o interface{}, text string) {
-	if GetConfig(context.TODO()).UseJSONLog {
-		logJSON(level, o, text)
-	} else {
-		logPlain(level, o, text)
-	}
+func LogPrint(level LogLevel, o any, text string) {
+	logSlogWithObject(level, o, text, nil)
 }
 
 // LogPrintf produces a log string from the arguments passed in
-func LogPrintf(level LogLevel, o interface{}, text string, args ...interface{}) {
-	if GetConfig(context.TODO()).UseJSONLog {
-		logJSONf(level, o, text, args...)
-	} else {
-		logPlainf(level, o, text, args...)
+func LogPrintf(level LogLevel, o any, text string, args ...any) {
+	text = fmt.Sprintf(text, args...)
+	var fields []any
+	for _, arg := range args {
+		if item, ok := arg.(LogValueItem); ok {
+			fields = append(fields, item.key, item.value)
+		}
 	}
+	logSlogWithObject(level, o, text, fields)
 }
 
 // LogLevelPrint writes logs at the given level
-func LogLevelPrint(level LogLevel, o interface{}, text string) {
+func LogLevelPrint(level LogLevel, o any, text string) {
 	if GetConfig(context.TODO()).LogLevel >= level {
 		LogPrint(level, o, text)
 	}
 }
 
 // LogLevelPrintf writes logs at the given level
-func LogLevelPrintf(level LogLevel, o interface{}, text string, args ...interface{}) {
+func LogLevelPrintf(level LogLevel, o any, text string, args ...any) {
 	if GetConfig(context.TODO()).LogLevel >= level {
 		LogPrintf(level, o, text, args...)
 	}
@@ -196,7 +183,7 @@ func LogLevelPrintf(level LogLevel, o interface{}, text string, args ...interfac
 
 // Panic writes alert log output for this Object or Fs and calls panic().
 // It should always be seen by the user.
-func Panic(o interface{}, text string) {
+func Panic(o any, text string) {
 	if GetConfig(context.TODO()).LogLevel >= LogLevelAlert {
 		LogPrint(LogLevelAlert, o, text)
 	}
@@ -205,50 +192,81 @@ func Panic(o interface{}, text string) {
 
 // Panicf writes alert log output for this Object or Fs and calls panic().
 // It should always be seen by the user.
-func Panicf(o interface{}, text string, args ...interface{}) {
+func Panicf(o any, text string, args ...any) {
 	if GetConfig(context.TODO()).LogLevel >= LogLevelAlert {
 		LogPrintf(LogLevelAlert, o, text, args...)
 	}
 	panic(fmt.Sprintf(text, args...))
 }
 
+// Panic if this called from an rc job.
+//
+// This means fatal errors get turned into panics which get caught by
+// the rc job handler so they don't crash rclone.
+//
+// This detects if we are being called from an rc Job by looking for
+// Job.run in the call stack.
+//
+// Ideally we would do this by passing a context about but we don't
+// have one with the logging calls yet.
+//
+// This is tested in fs/rc/internal_job_test.go in TestInternalFatal.
+func panicIfRcJob(o any, text string, args []any) {
+	if !caller.Present("(*Job).run") {
+		return
+	}
+	var errTxt strings.Builder
+	_, _ = errTxt.WriteString("fatal error: ")
+	if o != nil {
+		_, _ = fmt.Fprintf(&errTxt, "%v: ", o)
+	}
+	if args != nil {
+		_, _ = fmt.Fprintf(&errTxt, text, args...)
+	} else {
+		_, _ = errTxt.WriteString(text)
+	}
+	panic(errTxt.String())
+}
+
 // Fatal writes critical log output for this Object or Fs and calls os.Exit(1).
 // It should always be seen by the user.
-func Fatal(o interface{}, text string) {
+func Fatal(o any, text string) {
 	if GetConfig(context.TODO()).LogLevel >= LogLevelCritical {
 		LogPrint(LogLevelCritical, o, text)
 	}
+	panicIfRcJob(o, text, nil)
 	os.Exit(1)
 }
 
 // Fatalf writes critical log output for this Object or Fs and calls os.Exit(1).
 // It should always be seen by the user.
-func Fatalf(o interface{}, text string, args ...interface{}) {
+func Fatalf(o any, text string, args ...any) {
 	if GetConfig(context.TODO()).LogLevel >= LogLevelCritical {
 		LogPrintf(LogLevelCritical, o, text, args...)
 	}
+	panicIfRcJob(o, text, args)
 	os.Exit(1)
 }
 
 // Error writes error log output for this Object or Fs.  It
 // should always be seen by the user.
-func Error(o interface{}, text string) {
+func Error(o any, text string) {
 	LogLevelPrint(LogLevelError, o, text)
 }
 
 // Errorf writes error log output for this Object or Fs.  It
 // should always be seen by the user.
-func Errorf(o interface{}, text string, args ...interface{}) {
+func Errorf(o any, text string, args ...any) {
 	LogLevelPrintf(LogLevelError, o, text, args...)
 }
 
 // Print writes log output for this Object or Fs, same as Logf.
-func Print(o interface{}, text string) {
+func Print(o any, text string) {
 	LogLevelPrint(LogLevelNotice, o, text)
 }
 
 // Printf writes log output for this Object or Fs, same as Logf.
-func Printf(o interface{}, text string, args ...interface{}) {
+func Printf(o any, text string, args ...any) {
 	LogLevelPrintf(LogLevelNotice, o, text, args...)
 }
 
@@ -257,7 +275,7 @@ func Printf(o interface{}, text string, args ...interface{}) {
 // By default rclone should not log very much so only use this for
 // important things the user should see.  The user can filter these
 // out with the -q flag.
-func Log(o interface{}, text string) {
+func Log(o any, text string) {
 	LogLevelPrint(LogLevelNotice, o, text)
 }
 
@@ -266,7 +284,7 @@ func Log(o interface{}, text string) {
 // By default rclone should not log very much so only use this for
 // important things the user should see.  The user can filter these
 // out with the -q flag.
-func Logf(o interface{}, text string, args ...interface{}) {
+func Logf(o any, text string, args ...any) {
 	LogLevelPrintf(LogLevelNotice, o, text, args...)
 }
 
@@ -274,32 +292,32 @@ func Logf(o interface{}, text string, args ...interface{}) {
 // level for logging transfers, deletions and things which should
 // appear with the -v flag.
 // There is name class on "Info", hence the name "Infoc", "c" for constant.
-func Infoc(o interface{}, text string) {
+func Infoc(o any, text string) {
 	LogLevelPrint(LogLevelInfo, o, text)
 }
 
 // Infof writes info on transfers for this Object or Fs.  Use this
 // level for logging transfers, deletions and things which should
 // appear with the -v flag.
-func Infof(o interface{}, text string, args ...interface{}) {
+func Infof(o any, text string, args ...any) {
 	LogLevelPrintf(LogLevelInfo, o, text, args...)
 }
 
 // Debug writes debugging output for this Object or Fs.  Use this for
 // debug only.  The user must have to specify -vv to see this.
-func Debug(o interface{}, text string) {
+func Debug(o any, text string) {
 	LogLevelPrint(LogLevelDebug, o, text)
 }
 
 // Debugf writes debugging output for this Object or Fs.  Use this for
 // debug only.  The user must have to specify -vv to see this.
-func Debugf(o interface{}, text string, args ...interface{}) {
+func Debugf(o any, text string, args ...any) {
 	LogLevelPrintf(LogLevelDebug, o, text, args...)
 }
 
 // LogDirName returns an object for the logger, logging a root
 // directory which would normally be "" as the Fs
-func LogDirName(f Fs, dir string) interface{} {
+func LogDirName(f Fs, dir string) any {
 	if dir != "" {
 		return dir
 	}
