@@ -163,7 +163,7 @@ func (ls *listDirs) WalkFn(dir string, entries fs.DirEntries, err error) error {
 // Walk does the walk and tests the expectations
 func (ls *listDirs) Walk() {
 	err := walk(context.Background(), nil, "", ls.includeAll, ls.maxLevel, ls.WalkFn, ls.ListDir)
-	assert.Equal(ls.t, ls.finalError, err)
+	assert.True(ls.t, errors.Is(ls.finalError, err))
 	ls.IsFinished()
 }
 
@@ -798,7 +798,8 @@ func TestListR(t *testing.T) {
 		mockobject.Object("dir/b"),
 		mockobject.Object("dir/c"),
 	}
-	f := mockfs.NewFs(ctx, "mock", "/")
+	f, err := mockfs.NewFs(ctx, "mock", "/", nil)
+	require.NoError(t, err)
 	var got []string
 	clearCallback := func() {
 		got = nil
