@@ -108,7 +108,7 @@ func (conf *Config) MakeOauth2Config() *oauth2.Config {
 	return &oauth2.Config{
 		ClientID:     conf.ClientID,
 		ClientSecret: conf.ClientSecret,
-		RedirectURL:  RedirectLocalhostURL,
+		RedirectURL:  conf.RedirectURL,
 		Scopes:       conf.Scopes,
 		Endpoint: oauth2.Endpoint{
 			AuthURL:   conf.AuthURL,
@@ -155,7 +155,7 @@ var SharedOptions = []fs.Option{{
 }, {
 	Name:     config.ConfigClientCredentials,
 	Default:  false,
-	Help:     "Use client credentials OAuth flow.\n\nThis will use the OAUTH2 client Credentials Flow as described in RFC 6749.",
+	Help:     "Use client credentials OAuth flow.\n\nThis will use the OAUTH2 client Credentials Flow as described in RFC 6749.\n\nNote that this option is NOT supported by all backends.",
 	Advanced: true,
 }}
 
@@ -250,9 +250,7 @@ func (ts *TokenSource) reReadToken() (changed bool) {
 		return false
 	}
 
-	if !newToken.Valid() {
-		fs.Debugf(ts.name, "Loaded invalid token from config file - ignoring")
-	} else {
+	if newToken.Valid() {
 		fs.Debugf(ts.name, "Loaded fresh token from config file")
 		changed = true
 	}
@@ -264,6 +262,8 @@ func (ts *TokenSource) reReadToken() (changed bool) {
 	if changed {
 		ts.token = newToken
 		ts.tokenSource = nil // invalidate since we changed the token
+	} else {
+		fs.Debugf(ts.name, "No updated token found in the config file")
 	}
 	return changed
 }
@@ -319,6 +319,8 @@ func (ts *TokenSource) Token() (*oauth2.Token, error) {
 		return ts.token, nil
 	}
 
+	fs.Debug(ts.name, "Token expired")
+
 	// Try getting the token a few times
 	for i := 1; i <= maxTries; i++ {
 		// Try reading the token from the config file in case it has
@@ -344,6 +346,7 @@ func (ts *TokenSource) Token() (*oauth2.Token, error) {
 
 		token, err = ts.tokenSource.Token()
 		if err == nil {
+			fs.Debug(ts.name, "Token refresh successful")
 			break
 		}
 		if newErr := maybeWrapOAuthError(err, ts.name); newErr != err {
